Collection Manager
==================

Manages Anki collection lifecycle and provides thread-safe access.

.. automodule:: mousetail.server.collection_manager
   :members:
   :undoc-members:
   :show-inheritance:

CollectionManager Class
-----------------------

.. autoclass:: mousetail.server.collection_manager.CollectionManager
   :members:
   :undoc-members:
   :show-inheritance:
   :special-members: __init__

Global Manager Function
-----------------------

.. autofunction:: mousetail.server.collection_manager.get_manager
